syntax = "proto3";

package Sindika.AspNet.App005.Services;

service DatasetService {
    rpc GetDataset(GetDatasetRequest) returns (GetDatasetResponse); 
}

message GetDatasetRequest {
    string dataset_id = 1;
}

message GetDatasetResponse {
    bool success = 1;      // Indicates if registration was successful
    string message = 2;    // Additional information
    repeated DatasetItem data = 3;
}

message DatasetItem {
    string file_path = 1;
    repeated DatasetItemAnnotation annotations = 2;
}

message DatasetItemAnnotation {
    string label = 1;
    double b_box_x1 = 2;
    double b_box_y1 = 3;
    double b_box_x2 = 4;
    double b_box_y2 = 5;
}