# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_training/protos/TrainingAgentService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_training/protos/TrainingAgentService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6nedo_vision_training/protos/TrainingAgentService.proto\x12\x1eSindika.AspNet.App005.Services\"\x86\x02\n\x1fTrainingAgentSystemUsageRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tcpu_usage\x18\x02 \x01(\x02\x12\x17\n\x0f\x63pu_temperature\x18\x03 \x01(\x02\x12\x19\n\x11ram_usage_percent\x18\x04 \x01(\x02\x12\x11\n\tram_total\x18\x05 \x01(\x04\x12\x10\n\x08ram_used\x18\x06 \x01(\x04\x12\x10\n\x08ram_free\x18\x07 \x01(\x04\x12\x42\n\x03gpu\x18\x08 \x03(\x0b\x32\x35.Sindika.AspNet.App005.Services.TrainingAgentGPUUsage\x12\x12\n\nlatency_ms\x18\t \x01(\x02\"\xc0\x01\n\x15TrainingAgentGPUUsage\x12\x11\n\tgpu_index\x18\x01 \x01(\x05\x12\x19\n\x11gpu_usage_percent\x18\x02 \x01(\x02\x12\x1c\n\x14memory_usage_percent\x18\x03 \x01(\x02\x12\x1b\n\x13temperature_celsius\x18\x04 \x01(\x02\x12\x14\n\x0ctotal_memory\x18\x05 \x01(\x04\x12\x13\n\x0bused_memory\x18\x06 \x01(\x04\x12\x13\n\x0b\x66ree_memory\x18\x07 \x01(\x04\"D\n TrainingAgentSystemUsageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"Y\n UpdateTrainingAgentStatusRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"E\n!UpdateTrainingAgentStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\")\n\x18GetConnectionInfoRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\xb9\x01\n\x19GetConnectionInfoResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrabbitmq_host\x18\x03 \x01(\t\x12\x15\n\rrabbitmq_port\x18\x04 \x01(\x05\x12\x19\n\x11rabbitmq_username\x18\x05 \x01(\t\x12\x19\n\x11rabbitmq_password\x18\x06 \x01(\t\x12\x0f\n\x02id\x18\x07 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_id2\xce\x03\n\x14TrainingAgentService\x12\x94\x01\n\x0fSendSystemUsage\x12?.Sindika.AspNet.App005.Services.TrainingAgentSystemUsageRequest\x1a@.Sindika.AspNet.App005.Services.TrainingAgentSystemUsageResponse\x12\x93\x01\n\x0cUpdateStatus\x12@.Sindika.AspNet.App005.Services.UpdateTrainingAgentStatusRequest\x1a\x41.Sindika.AspNet.App005.Services.UpdateTrainingAgentStatusResponse\x12\x88\x01\n\x11GetConnectionInfo\x12\x38.Sindika.AspNet.App005.Services.GetConnectionInfoRequest\x1a\x39.Sindika.AspNet.App005.Services.GetConnectionInfoResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_training.protos.TrainingAgentService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRAININGAGENTSYSTEMUSAGEREQUEST']._serialized_start=91
  _globals['_TRAININGAGENTSYSTEMUSAGEREQUEST']._serialized_end=353
  _globals['_TRAININGAGENTGPUUSAGE']._serialized_start=356
  _globals['_TRAININGAGENTGPUUSAGE']._serialized_end=548
  _globals['_TRAININGAGENTSYSTEMUSAGERESPONSE']._serialized_start=550
  _globals['_TRAININGAGENTSYSTEMUSAGERESPONSE']._serialized_end=618
  _globals['_UPDATETRAININGAGENTSTATUSREQUEST']._serialized_start=620
  _globals['_UPDATETRAININGAGENTSTATUSREQUEST']._serialized_end=709
  _globals['_UPDATETRAININGAGENTSTATUSRESPONSE']._serialized_start=711
  _globals['_UPDATETRAININGAGENTSTATUSRESPONSE']._serialized_end=780
  _globals['_GETCONNECTIONINFOREQUEST']._serialized_start=782
  _globals['_GETCONNECTIONINFOREQUEST']._serialized_end=823
  _globals['_GETCONNECTIONINFORESPONSE']._serialized_start=826
  _globals['_GETCONNECTIONINFORESPONSE']._serialized_end=1011
  _globals['_TRAININGAGENTSERVICE']._serialized_start=1014
  _globals['_TRAININGAGENTSERVICE']._serialized_end=1476
# @@protoc_insertion_point(module_scope)
