# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_training/protos/DatasetService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_training/protos/DatasetService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0nedo_vision_training/protos/DatasetService.proto\x12\x1eSindika.AspNet.App005.Services\"\'\n\x11GetDatasetRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\t\"q\n\x12GetDatasetResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32+.Sindika.AspNet.App005.Services.DatasetItem\"l\n\x0b\x44\x61tasetItem\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12J\n\x0b\x61nnotations\x18\x02 \x03(\x0b\x32\x35.Sindika.AspNet.App005.Services.DatasetItemAnnotation\"n\n\x15\x44\x61tasetItemAnnotation\x12\r\n\x05label\x18\x01 \x01(\t\x12\x10\n\x08\x62_box_x1\x18\x02 \x01(\x01\x12\x10\n\x08\x62_box_y1\x18\x03 \x01(\x01\x12\x10\n\x08\x62_box_x2\x18\x04 \x01(\x01\x12\x10\n\x08\x62_box_y2\x18\x05 \x01(\x01\x32\x85\x01\n\x0e\x44\x61tasetService\x12s\n\nGetDataset\x12\x31.Sindika.AspNet.App005.Services.GetDatasetRequest\x1a\x32.Sindika.AspNet.App005.Services.GetDatasetResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_training.protos.DatasetService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETDATASETREQUEST']._serialized_start=84
  _globals['_GETDATASETREQUEST']._serialized_end=123
  _globals['_GETDATASETRESPONSE']._serialized_start=125
  _globals['_GETDATASETRESPONSE']._serialized_end=238
  _globals['_DATASETITEM']._serialized_start=240
  _globals['_DATASETITEM']._serialized_end=348
  _globals['_DATASETITEMANNOTATION']._serialized_start=350
  _globals['_DATASETITEMANNOTATION']._serialized_end=460
  _globals['_DATASETSERVICE']._serialized_start=463
  _globals['_DATASETSERVICE']._serialized_end=596
# @@protoc_insertion_point(module_scope)
