# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_training/protos/TrainingJobService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_training/protos/TrainingJobService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4nedo_vision_training/protos/TrainingJobService.proto\x12\x1eSindika.AspNet.App005.Services\"8\n\x16\x43reateStatusLogRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\";\n\x17\x43reateStatusLogResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\":\n\x17\x43reateCommandLogRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\"<\n\x18\x43reateCommandLogResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x90\x01\n\x17\x43reateMetricsLogRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\x12\x0e\n\x06map_50\x18\x03 \x01(\x01\x12\x11\n\tmap_50_95\x18\x04 \x01(\x01\x12\x11\n\tprecision\x18\x05 \x01(\x01\x12\x0e\n\x06recall\x18\x06 \x01(\x01\x12\x10\n\x08\x66\x31_score\x18\x07 \x01(\x01\"<\n\x18\x43reateMetricsLogResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"E\n\x1aUpdateModelFilePathRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x17\n\x0fmodel_file_path\x18\x02 \x01(\t\"?\n\x1bUpdateModelFilePathResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"{\n\x12UploadModelRequest\x12G\n\x08metadata\x18\x01 \x01(\x0b\x32\x33.Sindika.AspNet.App005.Services.UploadModelMetadataH\x00\x12\x14\n\nfile_chunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"8\n\x13UploadModelMetadata\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\"J\n\x13UploadModelResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t2\xb4\x05\n\x12TrainingJobService\x12\x82\x01\n\x0f\x43reateStatusLog\x12\x36.Sindika.AspNet.App005.Services.CreateStatusLogRequest\x1a\x37.Sindika.AspNet.App005.Services.CreateStatusLogResponse\x12\x85\x01\n\x10\x43reateCommandLog\x12\x37.Sindika.AspNet.App005.Services.CreateCommandLogRequest\x1a\x38.Sindika.AspNet.App005.Services.CreateCommandLogResponse\x12\x85\x01\n\x10\x43reateMetricsLog\x12\x37.Sindika.AspNet.App005.Services.CreateMetricsLogRequest\x1a\x38.Sindika.AspNet.App005.Services.CreateMetricsLogResponse\x12\x8e\x01\n\x13UpdateModelFilePath\x12:.Sindika.AspNet.App005.Services.UpdateModelFilePathRequest\x1a;.Sindika.AspNet.App005.Services.UpdateModelFilePathResponse\x12x\n\x0bUploadModel\x12\x32.Sindika.AspNet.App005.Services.UploadModelRequest\x1a\x33.Sindika.AspNet.App005.Services.UploadModelResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_training.protos.TrainingJobService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREATESTATUSLOGREQUEST']._serialized_start=88
  _globals['_CREATESTATUSLOGREQUEST']._serialized_end=144
  _globals['_CREATESTATUSLOGRESPONSE']._serialized_start=146
  _globals['_CREATESTATUSLOGRESPONSE']._serialized_end=205
  _globals['_CREATECOMMANDLOGREQUEST']._serialized_start=207
  _globals['_CREATECOMMANDLOGREQUEST']._serialized_end=265
  _globals['_CREATECOMMANDLOGRESPONSE']._serialized_start=267
  _globals['_CREATECOMMANDLOGRESPONSE']._serialized_end=327
  _globals['_CREATEMETRICSLOGREQUEST']._serialized_start=330
  _globals['_CREATEMETRICSLOGREQUEST']._serialized_end=474
  _globals['_CREATEMETRICSLOGRESPONSE']._serialized_start=476
  _globals['_CREATEMETRICSLOGRESPONSE']._serialized_end=536
  _globals['_UPDATEMODELFILEPATHREQUEST']._serialized_start=538
  _globals['_UPDATEMODELFILEPATHREQUEST']._serialized_end=607
  _globals['_UPDATEMODELFILEPATHRESPONSE']._serialized_start=609
  _globals['_UPDATEMODELFILEPATHRESPONSE']._serialized_end=672
  _globals['_UPLOADMODELREQUEST']._serialized_start=674
  _globals['_UPLOADMODELREQUEST']._serialized_end=797
  _globals['_UPLOADMODELMETADATA']._serialized_start=799
  _globals['_UPLOADMODELMETADATA']._serialized_end=855
  _globals['_UPLOADMODELRESPONSE']._serialized_start=857
  _globals['_UPLOADMODELRESPONSE']._serialized_end=931
  _globals['_TRAININGJOBSERVICE']._serialized_start=934
  _globals['_TRAININGJOBSERVICE']._serialized_end=1626
# @@protoc_insertion_point(module_scope)
